SystemOrganization addCategory: #'Seaside-Squeak-Core'!

!MessageSend methodsFor: '*Seaside-Squeak-Core' stamp: 'ab 7/10/2003 11:40'!
evaluateWithArguments: anArray
	^ self valueWithArguments: anArray! !

!String methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 3/23/2006 11:46'!
trimBlanks
	^self withBlanksTrimmed! !

!MIMEDocument methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 4/18/2006 20:09'!
asMIMEDocument
	^self! !

!MIMEDocument methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/2/2006 10:44'!
asMIMEDocumentType: mimeType
	^self! !

!BlockContext methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 10/28/2007 14:42'!
fixCallbackTemps
	"Fix the values of the temporary variables used in the block that are
	ordinarily shared with the method in which the block is defined.

	This is needed because Squeak is a crappy Smalltalk implementation
	that does not have full blcck closures."

	| temps |
	home := home copy.
	home swapSender: nil.
	home isMethodContext
		ifFalse: [ ^ self ].
	temps := self tempVarRefs.
	1 to: home size do: [ :index |
		(temps includes: index)
			ifFalse: [ home tempAt: index put: nil ] ]! !

!BlockContext methodsFor: '*Seaside-Squeak-Core' stamp: 'ab 2/11/2003 20:09'!
handleRequest: aRequest
	^ self value: aRequest! !

!BlockContext methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 10/28/2007 14:42'!
renderOn: aRenderer
	self numArgs = 0
		ifTrue: [self value]
		ifFalse: [self value: aRenderer]! !

!BlockContext methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 8/25/2007 16:26'!
tempVarRefs
	| method scanner end tempVars byte type offset |
	home ifNil: [ ^ false ].
	tempVars := Set new.
	method := self method.
	"Determine end of block from long jump preceding it"
	end := (method at: startpc - 2) \\ 16 - 4 * 256 + (method at: startpc - 1) + startpc - 1.
	scanner := InstructionStream new method: method pc: startpc.
	[ scanner pc <= end ] whileTrue: [
		byte  := scanner nextByte.
		type := byte // 16.
		offset := byte \\ 16.
		type = 1 ifTrue: [ tempVars add: offset + 1 ].
		scanner nextInstruction ].
	^ tempVars! !

!Behavior methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 10/30/2006 18:02'!
fullName
	"In VW, will include the namespace"
	^self name! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 5/22/2007 22:10'!
beMutable
	"for VW compatibility, a hack that allows to cache a value in a literal array"! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 11/20/2007 15:39'!
deprecatedApi
	self deprecatedApi: thisContext sender toString! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 11/21/2007 15:27'!
displayString
	"for compatibility purposes only"
	self deprecatedApi.
	^ self asString! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 3/19/2007 23:13'!
restoreFromSnapshot: anObject
	self copyFrom: anObject! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 3/15/2008 18:45'!
snapshotCopy
	^ self shallowCopy! !

!Object methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 11/20/2007 15:35'!
toString
	^self asString! !

Object subclass: #WAContinuation
	instanceVariableNames: 'values'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Squeak-Core'!

!WAContinuation commentStamp: 'pmm 6/1/2008 00:59' prior: 0!
A WAContinuation is the Squeak implementation of a continuation. It serializes the whole stack into an array

Instance Variables
	values:		<Array>

values
	- an Array of ContextParts and the values they store
!

!WAContinuation class methodsFor: 'instance creation' stamp: 'ab 6/15/2003 19:13'!
current
	^ self fromContext: thisContext sender! !

!WAContinuation class methodsFor: 'instance creation' stamp: 'ab 6/15/2003 19:13'!
currentDo: aBlock
	^ aBlock value: (self fromContext: thisContext sender)! !

!WAContinuation class methodsFor: 'instance creation' stamp: 'ab 6/15/2003 19:13'!
fromContext: aStack
	^self new initializeFromContext: aStack! !

!WAContinuation methodsFor: 'private' stamp: 'pmm 12/4/2007 20:30'!
initializeFromContext: aContext
	| valueStream context |
	valueStream := WriteStream on: (Array new: 20).
	context := aContext.
	[ context notNil ] whileTrue: [
		context serialiseOn: valueStream.
		context := context sender ].
	values := valueStream contents! !

!WAContinuation methodsFor: 'accessing' stamp: 'ab 6/15/2003 19:18'!
numArgs
	^ 1! !

!WAContinuation methodsFor: 'private' stamp: 'avi 4/24/2004 12:39'!
restoreValues
	| valueStream context |
	valueStream := values readStream.
	[valueStream atEnd] whileFalse:
		[context := valueStream next.
		1 to: context class instSize do: [:i | context instVarAt: i put: valueStream next].
		1 to: context localSize do: [:i | context localAt: i put: valueStream next]]! !

!WAContinuation methodsFor: 'private' stamp: 'lr 10/28/2007 14:42'!
terminate: aContext
	| context |
	context := aContext.
	[context notNil] whileTrue: [context := context swapSender: nil]! !

!WAContinuation methodsFor: 'evaluating' stamp: 'ab 6/15/2003 19:13'!
value
	self value: nil! !

!WAContinuation methodsFor: 'evaluating' stamp: 'lr 10/28/2007 14:42'!
value: anObject
	"Invoke the continuation and answer anObject as return value."

	self terminate: thisContext.
	self restoreValues.
	thisContext swapSender: values first.
	^ anObject! !

!WAContinuation methodsFor: 'evaluating' stamp: 'lr 10/28/2007 14:42'!
valueWithArguments: anArray
	anArray size = 1
		ifFalse: [ ^ self error: 'continuations can only be resumed with one argument' ].
	self value: anArray first! !

Object subclass: #WAProcessVariable
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Squeak-Core'!

!WAProcessVariable commentStamp: 'pmm 6/1/2008 01:01' prior: 0!
A WAProcessVariable is the Squeak implementation of a thread local variable. It abuses an unused instance variable in Process in order to avoid greater evils like monkey patching Process or WeakArrays.!

!WAProcessVariable class methodsFor: 'defauts' stamp: 'lr 3/29/2008 19:01'!
defaultValue
	^ nil! !

!WAProcessVariable class methodsFor: 'initialization' stamp: 'dkh 3/31/2008 12:33'!
reset
	"Primarily used for testing ... need a way to clear any pre-existing process variables."
	
	Processor activeProcess properties removeKey: self ifAbsent: []! !

!WAProcessVariable class methodsFor: 'evaluating' stamp: 'lr 4/28/2008 10:24'!
use: anObject during: aBlock
	Processor activeProcess properties 
		at: self put: anObject.
	^ aBlock ensure: [ 
		Processor activeProcess properties
			removeKey: self ifAbsent: [ ] ]! !

!WAProcessVariable class methodsFor: 'evaluating' stamp: 'jf 7/3/2008 12:13'!
value
	^ self valueForProcess: Processor activeProcess! !

!WAProcessVariable class methodsFor: 'evaluating' stamp: 'jf 7/3/2008 12:13'!
valueForProcess: aProcess
	^ aProcess properties at: self ifAbsent: [ self defaultValue ]! !

Object subclass: #WASqueakPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Squeak-Core'!

!WASqueakPlatform commentStamp: 'pmm 6/1/2008 01:03' prior: 0!
A WASqueakPlatform is the Squeak implementation of SeasidePlatformSupport, the Seaside class that provides functionality that can not be implemented in a platform independent way.
!

!WASqueakPlatform class methodsFor: 'startup' stamp: 'lr 1/5/2008 10:38'!
addToShutDownList: anObject
	"Add anObject to the shutdown-list of the system. On shutdown the message #shutDown will be sent to anObject."

	Smalltalk addToShutDownList: anObject! !

!WASqueakPlatform class methodsFor: 'startup' stamp: 'lr 1/5/2008 10:38'!
addToStartUpList: anObject
	"Add anObject to the startup-list of the system. On startup the message #startUp will be sent to anObject."

	Smalltalk addToStartUpList: anObject! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
asMethodReturningByteArray: aByteArrayOrString named: aSymbol
	"Generates the source of a method named aSymbol that returns aByteArrayOrString as a ByteArray"
	^self useByteArrayLiterals
		ifTrue: [ self asMethodReturningByteArrayLiteral: aByteArrayOrString named: aSymbol ]
		ifFalse: [ self asMethodReturningByteArrayWithCache: aByteArrayOrString named: aSymbol ]! !

!WASqueakPlatform class methodsFor: 'private-file-library' stamp: 'pmm 11/6/2007 20:59'!
asMethodReturningByteArrayLiteral: aByteArrayOrString named: aSymbol
	"Generates the source of a method named aSymbol that returns aByteArrayOrString as a byte array using VW/NewCompiler byte array literal syntax."
	^String streamContents: [ :stream |
		stream nextPutAll: aSymbol; cr.
		stream tab; nextPutAll: '^ #['.
		aByteArrayOrString asByteArray
			do: [ :each | each printOn: stream ]
			separatedBy: [ stream space ].
		stream nextPutAll: ']' ]! !

!WASqueakPlatform class methodsFor: 'private-file-library' stamp: 'pmm 11/6/2007 20:59'!
asMethodReturningByteArrayWithCache: aByteArrayOrString named: aSymbol
	"Generates the source of a method named aSymbol that returns aByteArrayOrString as a byte array and caching this array in a literal array of size 1."
	^ String streamContents: [ :stream |
		stream nextPutAll: aSymbol; cr.
		stream tab; nextPutAll: '| cache |'; cr.
		stream tab; nextPutAll: 'cache := #(nil) beMutable.'; cr.
		stream tab; nextPutAll: '(cache at: 1) isNil ifTrue: ['; cr.
		stream tab; tab; nextPutAll: 'cache at: 1 put: #('.
		aByteArrayOrString asByteArray
			do: [ :each | each printOn: stream ]
			separatedBy: [ stream space ].
		stream nextPutAll: ') asByteArray ].'; cr.
		stream tab; nextPutAll: '^ cache at: 1' ]! !

!WASqueakPlatform class methodsFor: 'encoding' stamp: 'pmm 11/6/2007 20:59'!
base64Decode: aString
	^ (Base64MimeConverter mimeDecodeToChars: aString readStream) contents! !

!WASqueakPlatform class methodsFor: 'tools' stamp: 'pmm 11/6/2007 20:59'!
commentCoverageFor: aString on: aStream
	"Calculates comment coverage for the category aString, includes exension methods.
	Transcript show: 'Category        Classes Comments    %   Methods Comments   %'; cr.
	self commentCoverageFor: 'Seaside' on: Transcript
	self commentCoverageFor: 'Scriptaculous' on: Transcript"

	| allClasses allMethods classesCommented methodsCommented info |
	allClasses := classesCommented := 0.
	allMethods := methodsCommented := 0.
	info := PackageInfo named: aString.
	info classes do: [ :theClass |
		allClasses := allClasses + 1.
		theClass hasComment
			ifTrue: [ classesCommented := classesCommented + 1 ] ].
	info methods do: [ :method |
		allMethods := allMethods + 1.
		(method actualClass firstPrecodeCommentFor: method methodSymbol)
			ifNotNil: [ methodsCommented := methodsCommented + 1 ] ].
	aStream nextPutAll: aString; tab.
	aStream print: allClasses; tab.
	aStream print: classesCommented; tab.
	aStream print: (100.0 * classesCommented / (allClasses max: 1) truncateTo: 0.01); tab.
	aStream print: allMethods; tab.
	aStream print: methodsCommented; tab.
	aStream print: (100.0 * methodsCommented / (allMethods max: 1) truncateTo: 0.01); cr.
	aStream flush! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
compile: aString into: aClass classified: aSymbol
	"The trick here is to be as silently a possible so that the package is not marked dirty when running WAFileLibrary test.
	This also makes running tests much faster."
	| methodNode compiledMethod selector methodAndNode |
	methodNode  := aClass compilerClass new
				compile: aString
				in: aClass
				notifying: nil
				ifFail: [ self error: 'syntax error' ].
	selector := methodNode selector.
	methodAndNode := (CompiledMethodWithNode generateMethodFromNode: methodNode trailer: aClass defaultMethodTrailer).
	compiledMethod := methodAndNode method.
	compiledMethod
			putSource: aString
			fromParseNode: methodAndNode node
			inFile: 2
			withPreamble: [ :file |
				file
					cr;
					nextPut: $!!;
					nextChunkPut: 'Behavior method';
					cr ].
	aClass addSelectorSilently: selector withMethod: compiledMethod.
	SystemChangeNotifier uniqueInstance
		doSilently: [ aClass organization classify: selector under: aSymbol ]! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
contentsOfFile: aString binary: aBoolean
	| stream |
	stream := aBoolean
		ifTrue: [ (FileDirectory default oldFileNamed: aString)
			binary;
			yourself ]
		ifFalse: [ (CrLfFileStream oldFileNamed: aString)
			ascii;
			yourself ].
	^[ stream contents ] ensure: [ stream close ]! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 4/12/2008 22:56'!
convertToSmalltalkNewlines: aString
	"convert any line endings (CR, CRLF, LF) to CR"
	aString isNil ifTrue: [ ^nil ].
	
	^String streamContents: [ :writeStream |
		| readStream |
		readStream := aString readStream.
		[ readStream atEnd ] whileFalse: [
			| next |
			next := readStream next.
			next = Character cr
				ifTrue: [
					readStream peek = Character lf
						ifTrue: [ readStream skip: 1 ].
					writeStream cr ]
				ifFalse: [
					next = Character lf
						ifTrue: [
							writeStream cr ]
						ifFalse: [
							writeStream nextPut: next] ] ] ]! !

!WASqueakPlatform class methodsFor: 'dispatchers' stamp: 'pmm 11/6/2007 20:59'!
defaultDispatcherName
	^'seaside'! !

!WASqueakPlatform class methodsFor: 'email' stamp: 'pmm 11/6/2007 20:59'!
deliverMailFrom: fromAddress to: recipientList text: messageText
	SMTPClient
		deliverMailFrom: fromAddress
		to: recipientList
		text: messageText
		usingServer: self smtpServer! !

!WASqueakPlatform class methodsFor: 'transactions' stamp: 'pmm 11/6/2007 20:59'!
doTransaction: aBlock
	"for Gemstone/S compatibility
	http://gemstonesoup.wordpress.com/2007/05/10/porting-application-specific-seaside-threads-to-gemstone/
	use when modifying an object from an outside thread"
	^aBlock value! !

!WASqueakPlatform class methodsFor: 'vm' stamp: 'pmm 11/6/2007 20:59'!
ensureAuthorInitials: aBlock
	"Makes sure the author initials for the image are set"
	Utilities authorInitialsPerSe isEmpty
		ifTrue: [Utilities setAuthorInitials: aBlock value]! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
ensureExistenceOfFolder: aString
	"creates a folder named aString in the image directory"
	FileDirectory default assureExistenceOfPath: aString! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
filesIn: aPathString
	"Return a collection of absolute paths for all the files (no directories) in the directory given by aPathString
	must not include file names that start with ."
	| directory |
	directory := FileDirectory default directoryNamed: aPathString.
	^(directory fileNames
		reject: [ :each | each first = $. ])
		collect: [ :each | directory fullNameFor: each ]! !

!WASqueakPlatform class methodsFor: 'initialization' stamp: 'lr 1/4/2008 23:10'!
initialize
	Smalltalk at: #SeasidePlatformSupport put: self! !

!WASqueakPlatform class methodsFor: 'testing' stamp: 'pmm 11/6/2007 20:59'!
isProxy: anObject
	^ (anObject class allSuperclasses includes: Object) not! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
localNameOf: aFilename
	^(FileDirectory on: aFilename) localName! !

!WASqueakPlatform class methodsFor: 'tools' stamp: 'pmm 1/5/2008 13:14'!
methodsOf: anAuthorString
	"Lists all the methods with author initials anAuthorString
	self methodsOf: 'avi'"

	| methods |
	methods := ((PackageInfo named: 'Seaside') methods select: [ :each |
			(each timeStamp copyUpTo: Character space) = anAuthorString ]).
	MessageSet
		openMessageList: methods
		name: methods size toString, ' methods of ', anAuthorString! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 11/6/2007 20:59'!
mimeDocumentClass
	^ MIMEDocument! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 4/21/2008 21:30'!
mimeDocumentOfType: type from: aFilename
	"WACachedDocument clearCache.
	(WACachedDocument fileName: 'SqueakDebug.log') asMIMEDocument.
	(WACachedDocument fileName: 'SqueakDebug.log') asMIMEDocument."


	| content mimeType |
	mimeType := type ifNil: [
		WAFileLibrary mimetypeFor: (FileDirectory extensionFor: aFilename) ].
	content := (StandardFileStream readOnlyFileNamed: aFilename) contentsOfEntireFile.
	^WACollectionMimeDocument
		contentType: mimeType
		content: content! !

!WASqueakPlatform class methodsFor: 'exceptions' stamp: 'pmm 11/6/2007 20:59'!
openDebuggerOn: anError
	| process |
	process := Processor activeProcess.
	WorldState addDeferredUIMessage:
		[process
			debug: anError signalerContext
			title: anError description
			full: true].
	process suspend! !

!WASqueakPlatform class methodsFor: 'accessing' stamp: 'pmm 2/11/2008 21:48'!
platformString
	"The platform string should include the name and version of the platform this version of Seaside is running on."

	^ SystemVersion current printString! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 1/17/2008 23:03'!
randomClass
	"used by Gemstone/S traditional Randoms which cannot be persisted"
	
	^Smalltalk
		at: #SecureRandom
		ifAbsent: [ Random ]! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 11/6/2007 20:59'!
readWriteStream
	^ RWBinaryOrTextStream on: (String new: 4096)! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 11/6/2007 20:59'!
reducedConflictDictionary
	"used by Gemstone/S reduced conflict classes that can be used to avoid transaction conflicts"
	^Dictionary! !

!WASqueakPlatform class methodsFor: 'startup' stamp: 'lr 1/5/2008 10:41'!
removeFromShutDownList: anObject
	"Remove anObject from the shutdown list in the system."

	Smalltalk removeFromShutDownList: anObject! !

!WASqueakPlatform class methodsFor: 'startup' stamp: 'lr 1/5/2008 10:41'!
removeFromStartUpList: anObject
	"Remove anObject from the startup list in the system."

	Smalltalk removeFromStartUpList: anObject! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
removeSelector: aSymbol from: aClass
	aClass removeSelectorSilently: aSymbol! !

!WASqueakPlatform class methodsFor: 'requests' stamp: 'pmm 11/6/2007 20:59'!
request: aString
	^self requestor request: aString! !

!WASqueakPlatform class methodsFor: 'requests' stamp: 'pmm 11/6/2007 20:59'!
request: aRequestString initialAnswer: anIntialAnserString
	^self requestor
		request: aRequestString
		initialAnswer: anIntialAnserString! !

!WASqueakPlatform class methodsFor: 'requests' stamp: 'pmm 11/6/2007 20:59'!
requestor
	^((Smalltalk hasClassNamed: #UIManager)
		ifTrue: [ (Smalltalk classNamed: #UIManager) default ]
		ifFalse: [ Smalltalk classNamed: #FillInTheBlank ])! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 11/6/2007 20:59'!
semaphoreClass
	"used by Gemstone/S traditional Semaphores which cannot be persisted"
	^Semaphore! !

!WASqueakPlatform class methodsFor: 'email' stamp: 'pmm 11/6/2007 20:59'!
smtpServer
	^ MailSender smtpServer! !

!WASqueakPlatform class methodsFor: 'exceptions' stamp: 'dkh 3/3/2008 20:31'!
stackDepth

	| depth current |
	depth := 0.
	current := thisContext.
	[ current isNil ] whileFalse: [
		current := current sender.
		depth := depth + 1 ].
	^ depth - 1! !

!WASqueakPlatform class methodsFor: 'private-file-library' stamp: 'pmm 11/6/2007 20:59'!
useByteArrayLiterals
	"whether ByteArray literals can/should be used"
	^Preferences
		valueOfFlag: #compileUseNewCompiler
		ifAbsent: [ false ]! !

!WASqueakPlatform class methodsFor: 'accessing' stamp: 'pmm 5/11/2008 08:10'!
utf8Codec
	"returns a new utf-8 codec"
	^WAUtf8SqueakCodec new! !

!WASqueakPlatform class methodsFor: 'accessing' stamp: 'lr 2/10/2008 17:33'!
versionString
	"The version string should include the currently loaded version of Seaside."

	^ (PackageInfo named: 'Seaside-Core') versionString! !

!WASqueakPlatform class methodsFor: 'vm' stamp: 'pmm 11/6/2007 20:59'!
vmStatisticsReportString
	^ SmalltalkImage current vmStatisticsReportString! !

!WASqueakPlatform class methodsFor: 'exceptions' stamp: 'pmm 11/6/2007 20:59'!
walkbackStringsFor: anError
	^(anError signalerContext sender stackOfSize: 20)
		collect: [:ctx | ctx printString]! !

!WASqueakPlatform class methodsFor: 'factory' stamp: 'pmm 11/6/2007 20:59'!
weakDictionaryOfSize: aNumber
	^IdentityDictionary new: aNumber! !

!WASqueakPlatform class methodsFor: 'file-library' stamp: 'pmm 11/6/2007 20:59'!
write: aStringOrByteArray toFile: aFileNameString inFolder: aFolderString
	"writes aStringOrByteArray to a file named aFilenameString in the folder aFolderString"
	| folder stream fullFilePath |
	folder := FileDirectory default directoryNamed: aFolderString.
	fullFilePath := folder fullNameFor: aFileNameString.
	stream := aStringOrByteArray isString
		ifTrue: [ (CrLfFileStream forceNewFileNamed: fullFilePath) ascii ]
		ifFalse: [ (FileStream forceNewFileNamed: fullFilePath) binary ].
	[ stream nextPutAll: aStringOrByteArray ]
		ensure: [ stream close ]! !

!PackageInfo methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 3/20/2008 07:03'!
versionString
	| package ancestor ancestors |
	package := (MCWorkingCopy registry keys detect: [ :each |
		each name = self packageName ]).
	ancestors := package workingCopy ancestry ancestors.
	ancestors isEmpty ifTrue: [ ^'unknown' ].
	ancestor := ancestors first.
	^ancestor name , '.mcz      ' , ancestor date printString, ' ', ancestor time printString! !

!Form methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 10/28/2007 14:42'!
asMIMEDocument
	^self asMIMEDocumentType: self defaultMimeType! !

!Form methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 1/22/2008 22:02'!
asMIMEDocumentType: mimeType
	| aStream |
	aStream := (RWBinaryOrTextStream on: '').
	(self writerForMimeType: mimeType)
		putForm: (self asFormOfDepth: 32) onStream: aStream.
	^MIMEDocument contentType: mimeType toString content: aStream contents! !

!Form methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/12/2006 14:00'!
defaultMimeType
	^'image/gif'! !

!Form methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/12/2006 14:01'!
mimeType
	^ self defaultMimeType! !

!Form methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/12/2006 14:02'!
writerForMimeType: mimeTypeString
	| mimeType tokens type |
	mimeType := mimeTypeString isString
		ifTrue: [mimeTypeString]
		ifFalse: [self mimeType].
	[tokens := mimeType findTokens: '/'.
	tokens size < 2] whileTrue: [mimeType := self defaultMimeType].
	"First token is assumed to be 'image'"
	type := tokens second.
	type = 'jpg' ifTrue: [^JPEGReadWriter2].
	type = 'jpeg' ifTrue: [^JPEGReadWriter2].
	type = 'png' ifTrue: [^PNGReadWriter].
	type = 'pcx' ifTrue: [^PCXReadWriter].
	type = 'bmp' ifTrue: [^BMPReadWriter].
	type = 'gif' ifTrue: [^GIFReadWriter].
	^nil! !

!Date class methodsFor: '*Seaside-Squeak-Core' stamp: 'dkh 3/10/2008 10:48'!
daysInMonthNumber: monthIndex forYear: yearInteger 

	^ Month daysInMonth: monthIndex forYear: yearInteger.
! !

!Date class methodsFor: '*Seaside-Squeak-Core' stamp: 'ab 7/10/2003 11:29'!
newDay: dayNumber monthNumber: monthNumber year: yearNumber
	^ self newDay: dayNumber month: monthNumber year: yearNumber! !

!Process methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 3/29/2008 21:23'!
properties
	^ errorHandler ifNil: [ errorHandler := WASmallDictionary new ]! !

!Bag methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 1/3/2008 18:25'!
restoreFromSnapshot: anObject
	super restoreFromSnapshot: anObject snapshotCopy! !

!Bag methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 4/20/2007 20:43'!
snapshotCopy
	^ self copy! !

!ContextPart methodsFor: '*Seaside-Squeak-Core' stamp: 'avi 4/24/2004 12:27'!
localAt: aNumber
	^ self at: aNumber! !

!ContextPart methodsFor: '*Seaside-Squeak-Core' stamp: 'avi 4/24/2004 12:27'!
localAt: aNumber put: anObject
	^ self at: aNumber put: anObject! !

!ContextPart methodsFor: '*Seaside-Squeak-Core' stamp: 'avi 4/24/2004 12:27'!
localSize
	^ self size! !

!ContextPart methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 12/4/2007 20:31'!
serialiseOn: aStream
	aStream nextPut: self.
	1 to: self class instSize do: [ :index |
		aStream nextPut: (self instVarAt: index) ].
	1 to: self localSize do: [ :index |
		aStream nextPut: (self localAt: index) ].! !

!Set methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 1/3/2008 18:25'!
restoreFromSnapshot: anObject
	super restoreFromSnapshot: anObject snapshotCopy! !

!Set methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 6/7/2007 22:14'!
snapshotCopy
	^ self copy! !

!PositionableStream methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 1/22/2008 22:05'!
asMIMEDocument
	^self asMIMEDocumentType: 'text/plain' toMimeType! !

!PositionableStream methodsFor: '*Seaside-Squeak-Core' stamp: 'pmm 1/22/2008 22:04'!
asMIMEDocumentType: mimeType
	^MIMELocalFileDocument contentType: mimeType toString contentStream:  self! !

!PositionableStream methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 10/28/2007 14:42'!
upToAndSkipThroughAll: aCollection
	"Needed for Seaside ports to other dialects where #upToAll: may have
	different semantics"
	^ self upToAll: aCollection! !

!OrderedCollection methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 11/16/2007 17:11'!
restoreFromSnapshot: anObject
	super restoreFromSnapshot: anObject snapshotCopy! !

!OrderedCollection methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 1/3/2008 18:25'!
snapshotCopy
	^ self copy! !

!Exception class methodsFor: '*Seaside-Squeak-Core' stamp: 'ab 7/10/2003 11:42'!
raiseSignal
	^ self signal! !

!Exception class methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 3/23/2006 17:53'!
raiseSignal: aString
	^ self signal: aString! !

!Exception methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 3/25/2008 10:07'!
raiseSignal
	^ self signal! !

!Exception methodsFor: '*Seaside-Squeak-Core' stamp: 'lr 3/25/2008 10:07'!
raiseSignal: aString
	^ self signal: aString! !

!Morph methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/2/2006 10:47'!
asMIMEDocument
	^self imageForm asMIMEDocument! !

!Morph methodsFor: '*Seaside-Squeak-Core' stamp: 'mb 6/2/2006 10:53'!
asMIMEDocumentType: mimeType
	^self imageForm asMIMEDocumentType: mimeType! !
WASqueakPlatform initialize!
